==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/NodeSpecFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface NodeSpecFluent<A extends NodeSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildConfigSource instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getConfigSource();
    public NodeConfigSource buildConfigSource();
    public A withConfigSource(NodeConfigSource configSource);
    public Boolean hasConfigSource();
    public NodeSpecFluent.ConfigSourceNested<A> withNewConfigSource();
    public NodeSpecFluent.ConfigSourceNested<A> withNewConfigSourceLike(NodeConfigSource item);
    public NodeSpecFluent.ConfigSourceNested<A> editConfigSource();
    public NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSource();
    public NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSourceLike(NodeConfigSource item);
    public String getExternalID();
    public A withExternalID(String externalID);
    public Boolean hasExternalID();
    public A withNewExternalID(StringBuilder arg1);
    public A withNewExternalID(int[] arg1,int arg2,int arg3);
    public A withNewExternalID(char[] arg1);
    public A withNewExternalID(StringBuffer arg1);
    public A withNewExternalID(byte[] arg1,int arg2);
    public A withNewExternalID(byte[] arg1);
    public A withNewExternalID(char[] arg1,int arg2,int arg3);
    public A withNewExternalID(byte[] arg1,int arg2,int arg3);
    public A withNewExternalID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewExternalID(String arg1);
    public String getPodCIDR();
    public A withPodCIDR(String podCIDR);
    public Boolean hasPodCIDR();
    public A withNewPodCIDR(StringBuilder arg1);
    public A withNewPodCIDR(int[] arg1,int arg2,int arg3);
    public A withNewPodCIDR(char[] arg1);
    public A withNewPodCIDR(StringBuffer arg1);
    public A withNewPodCIDR(byte[] arg1,int arg2);
    public A withNewPodCIDR(byte[] arg1);
    public A withNewPodCIDR(char[] arg1,int arg2,int arg3);
    public A withNewPodCIDR(byte[] arg1,int arg2,int arg3);
    public A withNewPodCIDR(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPodCIDR(String arg1);
    public A addToPodCIDRs(int index,String item);
    public A setToPodCIDRs(int index,String item);
    public A addToPodCIDRs(String... items);
    public A addAllToPodCIDRs(Collection<String> items);
    public A removeFromPodCIDRs(String... items);
    public A removeAllFromPodCIDRs(Collection<String> items);
    public List<String> getPodCIDRs();
    public String getPodCIDR(int index);
    public String getFirstPodCIDR();
    public String getLastPodCIDR();
    public String getMatchingPodCIDR(Predicate<String> predicate);
    public Boolean hasMatchingPodCIDR(Predicate<String> predicate);
    public A withPodCIDRs(List<String> podCIDRs);
    public A withPodCIDRs(String... podCIDRs);
    public Boolean hasPodCIDRs();
    public A addNewPodCIDR(StringBuilder arg1);
    public A addNewPodCIDR(int[] arg1,int arg2,int arg3);
    public A addNewPodCIDR(char[] arg1);
    public A addNewPodCIDR(StringBuffer arg1);
    public A addNewPodCIDR(byte[] arg1,int arg2);
    public A addNewPodCIDR(byte[] arg1);
    public A addNewPodCIDR(char[] arg1,int arg2,int arg3);
    public A addNewPodCIDR(byte[] arg1,int arg2,int arg3);
    public A addNewPodCIDR(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPodCIDR(String arg1);
    public String getProviderID();
    public A withProviderID(String providerID);
    public Boolean hasProviderID();
    public A withNewProviderID(StringBuilder arg1);
    public A withNewProviderID(int[] arg1,int arg2,int arg3);
    public A withNewProviderID(char[] arg1);
    public A withNewProviderID(StringBuffer arg1);
    public A withNewProviderID(byte[] arg1,int arg2);
    public A withNewProviderID(byte[] arg1);
    public A withNewProviderID(char[] arg1,int arg2,int arg3);
    public A withNewProviderID(byte[] arg1,int arg2,int arg3);
    public A withNewProviderID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewProviderID(String arg1);
    public A addToTaints(int index,Taint item);
    public A setToTaints(int index,Taint item);
    public A addToTaints(Taint... items);
    public A addAllToTaints(Collection<Taint> items);
    public A removeFromTaints(Taint... items);
    public A removeAllFromTaints(Collection<Taint> items);
    public A removeMatchingFromTaints(Predicate<TaintBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTaints instead.
 * @return The buildable object.
 */
@Deprecated public List<Taint> getTaints();
    public List<Taint> buildTaints();
    public Taint buildTaint(int index);
    public Taint buildFirstTaint();
    public Taint buildLastTaint();
    public Taint buildMatchingTaint(Predicate<TaintBuilder> predicate);
    public Boolean hasMatchingTaint(Predicate<TaintBuilder> predicate);
    public A withTaints(List<Taint> taints);
    public A withTaints(Taint... taints);
    public Boolean hasTaints();
    public A addNewTaint(String effect,String key,String timeAdded,String value);
    public NodeSpecFluent.TaintsNested<A> addNewTaint();
    public NodeSpecFluent.TaintsNested<A> addNewTaintLike(Taint item);
    public NodeSpecFluent.TaintsNested<A> setNewTaintLike(int index,Taint item);
    public NodeSpecFluent.TaintsNested<A> editTaint(int index);
    public NodeSpecFluent.TaintsNested<A> editFirstTaint();
    public NodeSpecFluent.TaintsNested<A> editLastTaint();
    public NodeSpecFluent.TaintsNested<A> editMatchingTaint(Predicate<TaintBuilder> predicate);
    public Boolean getUnschedulable();
    public A withUnschedulable(Boolean unschedulable);
    public Boolean hasUnschedulable();
    public A withNewUnschedulable(String arg1);
    public A withNewUnschedulable(boolean arg1);
    public interface ConfigSourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<NodeSpecFluent.ConfigSourceNested<N>> {

            public N and();
            public N endConfigSource();    }


    public interface TaintsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TaintFluent<NodeSpecFluent.TaintsNested<N>> {

            public N and();
            public N endTaint();    }


}

==> kubernetes-model-core-5.3.2-sources.jar: io/fabric8/kubernetes/api/model/NodeSpecFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface NodeSpecFluent<A extends NodeSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildConfigSource instead.
 * @return The buildable object.
 */
@Deprecated public NodeConfigSource getConfigSource();
    public NodeConfigSource buildConfigSource();
    public A withConfigSource(NodeConfigSource configSource);
    public Boolean hasConfigSource();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.ConfigSourceNested<A> withNewConfigSource();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.ConfigSourceNested<A> withNewConfigSourceLike(NodeConfigSource item);
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.ConfigSourceNested<A> editConfigSource();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSource();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.ConfigSourceNested<A> editOrNewConfigSourceLike(NodeConfigSource item);
    public String getExternalID();
    public A withExternalID(String externalID);
    public Boolean hasExternalID();
    public A withNewExternalID(StringBuilder arg1);
    public A withNewExternalID(int[] arg1,int arg2,int arg3);
    public A withNewExternalID(char[] arg1);
    public A withNewExternalID(StringBuffer arg1);
    public A withNewExternalID(byte[] arg1,int arg2);
    public A withNewExternalID(byte[] arg1);
    public A withNewExternalID(char[] arg1,int arg2,int arg3);
    public A withNewExternalID(byte[] arg1,int arg2,int arg3);
    public A withNewExternalID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewExternalID(String arg1);
    public String getPodCIDR();
    public A withPodCIDR(String podCIDR);
    public Boolean hasPodCIDR();
    public A withNewPodCIDR(StringBuilder arg1);
    public A withNewPodCIDR(int[] arg1,int arg2,int arg3);
    public A withNewPodCIDR(char[] arg1);
    public A withNewPodCIDR(StringBuffer arg1);
    public A withNewPodCIDR(byte[] arg1,int arg2);
    public A withNewPodCIDR(byte[] arg1);
    public A withNewPodCIDR(char[] arg1,int arg2,int arg3);
    public A withNewPodCIDR(byte[] arg1,int arg2,int arg3);
    public A withNewPodCIDR(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPodCIDR(String arg1);
    public A addToPodCIDRs(int index,String item);
    public A setToPodCIDRs(int index,String item);
    public A addToPodCIDRs(String... items);
    public A addAllToPodCIDRs(Collection<String> items);
    public A removeFromPodCIDRs(String... items);
    public A removeAllFromPodCIDRs(Collection<String> items);
    public List<String> getPodCIDRs();
    public String getPodCIDR(int index);
    public String getFirstPodCIDR();
    public String getLastPodCIDR();
    public String getMatchingPodCIDR(Predicate<String> predicate);
    public Boolean hasMatchingPodCIDR(Predicate<String> predicate);
    public A withPodCIDRs(List<String> podCIDRs);
    public A withPodCIDRs(String... podCIDRs);
    public Boolean hasPodCIDRs();
    public A addNewPodCIDR(StringBuilder arg1);
    public A addNewPodCIDR(int[] arg1,int arg2,int arg3);
    public A addNewPodCIDR(char[] arg1);
    public A addNewPodCIDR(StringBuffer arg1);
    public A addNewPodCIDR(byte[] arg1,int arg2);
    public A addNewPodCIDR(byte[] arg1);
    public A addNewPodCIDR(char[] arg1,int arg2,int arg3);
    public A addNewPodCIDR(byte[] arg1,int arg2,int arg3);
    public A addNewPodCIDR(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPodCIDR(String arg1);
    public String getProviderID();
    public A withProviderID(String providerID);
    public Boolean hasProviderID();
    public A withNewProviderID(StringBuilder arg1);
    public A withNewProviderID(int[] arg1,int arg2,int arg3);
    public A withNewProviderID(char[] arg1);
    public A withNewProviderID(StringBuffer arg1);
    public A withNewProviderID(byte[] arg1,int arg2);
    public A withNewProviderID(byte[] arg1);
    public A withNewProviderID(char[] arg1,int arg2,int arg3);
    public A withNewProviderID(byte[] arg1,int arg2,int arg3);
    public A withNewProviderID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewProviderID(String arg1);
    public A addToTaints(int index,Taint item);
    public A setToTaints(int index,Taint item);
    public A addToTaints(Taint... items);
    public A addAllToTaints(Collection<Taint> items);
    public A removeFromTaints(Taint... items);
    public A removeAllFromTaints(Collection<Taint> items);
    public A removeMatchingFromTaints(Predicate<TaintBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTaints instead.
 * @return The buildable object.
 */
@Deprecated public List<Taint> getTaints();
    public List<Taint> buildTaints();
    public Taint buildTaint(int index);
    public Taint buildFirstTaint();
    public Taint buildLastTaint();
    public Taint buildMatchingTaint(Predicate<TaintBuilder> predicate);
    public Boolean hasMatchingTaint(Predicate<TaintBuilder> predicate);
    public A withTaints(List<Taint> taints);
    public A withTaints(Taint... taints);
    public Boolean hasTaints();
    public A addNewTaint(String effect,String key,String timeAdded,String value);
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> addNewTaint();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> addNewTaintLike(Taint item);
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> setNewTaintLike(int index,Taint item);
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> editTaint(int index);
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> editFirstTaint();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> editLastTaint();
    public io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<A> editMatchingTaint(Predicate<TaintBuilder> predicate);
    public Boolean getUnschedulable();
    public A withUnschedulable(Boolean unschedulable);
    public Boolean hasUnschedulable();
    public A withNewUnschedulable(String arg1);
    public A withNewUnschedulable(boolean arg1);
    public interface ConfigSourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeConfigSourceFluent<io.fabric8.kubernetes.api.model.NodeSpecFluent.ConfigSourceNested<N>> {

            public N and();
            public N endConfigSource();    }


    public interface TaintsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TaintFluent<io.fabric8.kubernetes.api.model.NodeSpecFluent.TaintsNested<N>> {

            public N and();
            public N endTaint();    }


}
